
# Type: datetime


The combination of a date and time

URI: [https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Datetime](https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Datetime)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **XSDDateTime** |
| Representation | | str |
